# Changelog

<!--next-version-placeholder-->

## v1.6.1 (2022-05-30)
### Fix
* Fix env variables ([#6](https://github.com/draganagrbic998/devops_profile_service/issues/6)) ([`c076354`](https://github.com/draganagrbic998/devops_profile_service/commit/c076354cd668b5ebe3dcbbec2daaf90bfb517f53))

## v1.6.0 (2022-05-29)
### Feature
* Monitoring feature ([#5](https://github.com/draganagrbic998/devops_profile_service/issues/5)) ([`7dc2891`](https://github.com/draganagrbic998/devops_profile_service/commit/7dc28914fc52a0073b579e48c20059091beee32b))

## v1.5.0 (2022-05-28)
### Feature
* Events, tracing and logging feature ([#4](https://github.com/draganagrbic998/devops_profile_service/issues/4)) ([`9156cc3`](https://github.com/draganagrbic998/devops_profile_service/commit/9156cc3bc2b60d1f8c4fde2ae016e38189a468d8))

## v1.4.0 (2022-05-21)
### Feature
* Connect/block profile + notifications feature ([#3](https://github.com/draganagrbic998/devops_profile_service3/issues/3)) ([`4241d96`](https://github.com/draganagrbic998/devops_profile_service3/commit/4241d963c90dfb44026c5602103817ef8f044ac9))

## v1.3.0 (2022-05-21)
### Feature
* Read/update profile feature ([#2](https://github.com/draganagrbic998/devops_profile_service3/issues/2)) ([`816d9fe`](https://github.com/draganagrbic998/devops_profile_service3/commit/816d9fea4bbc64a33e7360a98491bc338be3c73b))

## v1.2.0 (2022-05-21)
### Feature
* Read/search offers feature ([#1](https://github.com/draganagrbic998/devops_profile_service3/issues/1)) ([`6de0180`](https://github.com/draganagrbic998/devops_profile_service3/commit/6de01809cfe2f82f9c17a438b34231a69463f612))

## v1.1.0 (2022-05-21)
### Feature
* Init profile service ([`a48c1fe`](https://github.com/draganagrbic998/devops_profile_service3/commit/a48c1fee598127b0b557cbb8bcbe3d08bb0c78d3))
